@@ -1,8 +1,8 @@
 #######################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.20/lib/Perl/Critic/Policy/CodeLayout/ProhibitHardTabs.pm $
-#     $Date: 2006-09-10 21:18:18 -0700 (Sun, 10 Sep 2006) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.21/lib/Perl/Critic/Policy/CodeLayout/ProhibitHardTabs.pm $
+#     $Date: 2006-11-05 18:01:38 -0800 (Sun, 05 Nov 2006) $
 #   $Author: thaljef $
-# $Revision: 663 $
+# $Revision: 809 $
 # ex: set ts=8 sts=4 sw=4 expandtab
 ########################################################################
 
@@ -13,7 +13,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 
 my $desc = q{Hard tabs used};
 my $expl = [ 20 ];
@@ -21,6 +21,7 @@ my $expl = [ 20 ];
 #----------------------------------------------------------------------------
 
 sub default_severity { return $SEVERITY_MEDIUM }
+sub default_themes { return qw(cosmetic) };
 sub applies_to { return 'PPI::Token' }
 
 #----------------------------------------------------------------------------
@@ -43,9 +44,7 @@ sub violates {
     $elem =~ m{ \t }mx || return;
 
     # The __DATA__ element is exempt
-    if (my $parent = $elem->parent() ) {
-        return if $parent->isa('PPI::Statement::Data');
-    }
+    return if $elem->parent->isa('PPI::Statement::Data');
 
     # Permit leading tabs, if allowed
     return if $self->{_allow_leading_tabs} && $elem->location->[1] == 1;
