@@ -1,8 +1,8 @@
 #######################################################################
-#      $URL$
-#     $Date$
-#   $Author$
-# $Revision$
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.21/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitEscapedCharacters.pm $
+#     $Date: 2006-11-05 18:01:38 -0800 (Sun, 05 Nov 2006) $
+#   $Author: thaljef $
+# $Revision: 809 $
 ########################################################################
 
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitEscapedCharacters;
@@ -12,7 +12,7 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 
 #---------------------------------------------------------------------------
 
@@ -21,11 +21,10 @@ my $expl     = [ 56 ];
 
 #---------------------------------------------------------------------------
 
-sub default_severity { return $SEVERITY_LOW }
-sub applies_to {
-    return qw(PPI::Token::Quote::Double
-              PPI::Token::Quote::Interpolate);
-}
+sub default_severity { return $SEVERITY_LOW       }
+sub default_themes   { return qw(pbp readability) }
+sub applies_to       { return qw(PPI::Token::Quote::Double
+                                 PPI::Token::Quote::Interpolate) }
 
 #---------------------------------------------------------------------------
 
