@@ -1,8 +1,9 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.21_01/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitMismatchedOperators.pm $
-#     $Date: 2006-12-03 23:40:05 -0800 (Sun, 03 Dec 2006) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.21/lib/Perl/Critic/Policy/ValuesAndExpressions/ProhibitMismatchedOperators.pm $
+#     $Date: 2006-11-05 18:01:38 -0800 (Sun, 05 Nov 2006) $
 #   $Author: thaljef $
-# $Revision: 1030 $
+# $Revision: 809 $
+# ex: set ts=8 sts=4 sw=4 expandtab
 ##############################################################################
 
 package Perl::Critic::Policy::ValuesAndExpressions::ProhibitMismatchedOperators;
@@ -11,12 +12,11 @@ use warnings;
 use Perl::Critic::Utils;
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 0.21_01;
+our $VERSION = 0.21;
 
-#-----------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
 my $desc = q{Mismatched operator};
-my $expl = q{Numeric/string operators and operands should match};
 
 # operator types
 
@@ -35,18 +35,17 @@ my %token_compat = (
     'PPI::Token::Quote'  => [ 0, 1 ],
 );
 
-#-----------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
-sub default_severity { return $SEVERITY_LOW          }
-sub default_themes   { return qw( readability )      }
-sub applies_to       { return 'PPI::Token::Operator' }
+sub default_severity { return $SEVERITY_LOW; }
+sub applies_to { return 'PPI::Token::Operator'; }
 
-#-----------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
 sub violates {
     my ( $self, $elem ) = @_;
 
-    my $elem_text = $elem->content;
+    my $elem_text = "$elem";
 
     return if !exists $op_types{$elem_text};
 
@@ -73,10 +72,10 @@ sub violates {
     return if ( !defined $prev_compat || $prev_compat->[$op_type] )
         && ( !defined $next_compat || $next_compat->[$op_type] );
 
-    return $self->violation( $desc, $expl, $elem );
+    return $self->violation( $desc, undef, $elem );
 }
 
-#-----------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
 # get token value compatibility
 
@@ -92,7 +91,7 @@ sub _get_token_compat {
 
 __END__
 
-#-----------------------------------------------------------------------------
+#---------------------------------------------------------------------------
 
 =pod
 
@@ -131,12 +130,3 @@ it under the same terms as Perl itself.  The full text of this license
 can be found in the LICENSE file included with this module.
 
 =cut
-
-# Local Variables:
-#   mode: cperl
-#   cperl-indent-level: 4
-#   fill-column: 78
-#   indent-tabs-mode: nil
-#   c-indentation-style: bsd
-# End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
