@@ -1,8 +1,8 @@
 #######################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.20/lib/Perl/Critic/Policy/Variables/ProhibitPackageVars.pm $
-#     $Date: 2006-09-10 21:18:18 -0700 (Sun, 10 Sep 2006) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.21/lib/Perl/Critic/Policy/Variables/ProhibitPackageVars.pm $
+#     $Date: 2006-11-05 18:01:38 -0800 (Sun, 05 Nov 2006) $
 #   $Author: thaljef $
-# $Revision: 663 $
+# $Revision: 809 $
 # ex: set ts=8 sts=4 sw=4 expandtab
 ########################################################################
 
@@ -14,7 +14,7 @@ use Perl::Critic::Utils;
 use List::MoreUtils qw(all);
 use base 'Perl::Critic::Policy';
 
-our $VERSION = 0.20;
+our $VERSION = 0.21;
 
 #---------------------------------------------------------------------------
 
@@ -23,12 +23,11 @@ my $expl = [ 73, 75 ];
 
 #---------------------------------------------------------------------------
 
-sub default_severity { return $SEVERITY_MEDIUM }
-sub applies_to {
-    return qw( PPI::Token::Symbol
-               PPI::Statement::Variable
-               PPI::Statement::Include );
-}
+sub default_severity { return $SEVERITY_MEDIUM    }
+sub default_themes   { return qw(pbp unreliable) }
+sub applies_to       { return qw(PPI::Token::Symbol
+                                 PPI::Statement::Variable
+                                 PPI::Statement::Include) }
 
 #---------------------------------------------------------------------------
 
