@@ -1,8 +1,9 @@
 ##############################################################################
-#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.21_01/lib/Perl/Critic/UserProfile.pm $
-#     $Date: 2006-12-03 23:40:05 -0800 (Sun, 03 Dec 2006) $
+#      $URL: http://perlcritic.tigris.org/svn/perlcritic/tags/Perl-Critic-0.21/lib/Perl/Critic/UserProfile.pm $
+#     $Date: 2006-11-05 18:01:38 -0800 (Sun, 05 Nov 2006) $
 #   $Author: thaljef $
-# $Revision: 1030 $
+# $Revision: 809 $
+# ex: set ts=8 sts=4 sw=4 expandtab
 ##############################################################################
 
 package Perl::Critic::UserProfile;
@@ -16,7 +17,7 @@ use File::Spec qw();
 use Perl::Critic::Defaults qw();
 use Perl::Critic::Utils;
 
-our $VERSION = 0.21_01;
+our $VERSION = 0.21;
 
 #-----------------------------------------------------------------------------
 
@@ -123,12 +124,8 @@ sub _set_defaults {
 sub _load_profile_from_file {
     my $file = shift || return {};
     my $prof = Config::Tiny->read($file);
-    if (defined $prof) {
-        return $prof;
-    } else {
-        croak(sprintf qq{Config::Tiny could not parse profile '%s':\n\t%s\n},
-              $file, Config::Tiny::errstr());
-    }
+    croak( "Profile error: $file: " . Config::Tiny::errstr() ) if not defined $prof;
+    return $prof;
 }
 
 #-----------------------------------------------------------------------------
@@ -274,12 +271,3 @@ it under the same terms as Perl itself.  The full text of this license
 can be found in the LICENSE file included with this module.
 
 =cut
-
-# Local Variables:
-#   mode: cperl
-#   cperl-indent-level: 4
-#   fill-column: 78
-#   indent-tabs-mode: nil
-#   c-indentation-style: bsd
-# End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
